@@ -9,23 +9,18 @@
 #include <linux/sched.h>
 #include <linux/pid_namespace.h>
 #include <linux/binfmts.h>
-#include <lttng-kernel-version.h>
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,9,0))
+#include <linux/version.h>
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,9,0))
 #include <linux/sched/rt.h>
 #endif
-
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,19,0))
-#define lttng_proc_inum ns.inum
-#else
-#define lttng_proc_inum proc_inum
-#endif
+#include <wrapper/namespace.h>
 
 #define LTTNG_MAX_PID_NS_LEVEL 32
 
 #ifndef _TRACE_SCHED_DEF_
 #define _TRACE_SCHED_DEF_
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,15,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,15,0))
 
 static inline long __trace_sched_switch_state(bool preempt, struct task_struct *p)
 {
@@ -53,7 +48,7 @@ static inline long __trace_sched_switch_state(bool preempt, struct task_struct *
         return state ? (1 << (state - 1)) : state;
 }
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,14,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(4,14,0))
 
 static inline long __trace_sched_switch_state(bool preempt, struct task_struct *p)
 {
@@ -81,7 +76,7 @@ static inline long __trace_sched_switch_state(bool preempt, struct task_struct *
         return state ? (1 << (state - 1)) : state;
 }
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,4,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(4,4,0))
 
 static inline long __trace_sched_switch_state(bool preempt, struct task_struct *p)
 {
@@ -95,7 +90,7 @@ static inline long __trace_sched_switch_state(bool preempt, struct task_struct *
 	return preempt ? TASK_RUNNING | TASK_STATE_MAX : p->state;
 }
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,19,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,19,0))
 
 static inline long __trace_sched_switch_state(struct task_struct *p)
 {
@@ -115,7 +110,7 @@ static inline long __trace_sched_switch_state(struct task_struct *p)
 	return state;
 }
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,13,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,13,0))
 
 static inline long __trace_sched_switch_state(struct task_struct *p)
 {
@@ -132,7 +127,7 @@ static inline long __trace_sched_switch_state(struct task_struct *p)
 	return state;
 }
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,2,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,2,0))
 
 static inline long __trace_sched_switch_state(struct task_struct *p)
 {
@@ -149,7 +144,7 @@ static inline long __trace_sched_switch_state(struct task_struct *p)
 	return state;
 }
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35))
+#else
 
 static inline long __trace_sched_switch_state(struct task_struct *p)
 {
@@ -170,6 +165,40 @@ static inline long __trace_sched_switch_state(struct task_struct *p)
 
 #endif /* _TRACE_SCHED_DEF_ */
 
+/*
+ * Enumeration of the task state bitmask.
+ * Only bit flags are enumerated here, not composition of states.
+ */
+LTTNG_TRACEPOINT_ENUM(task_state,
+	TP_ENUM_VALUES(
+		ctf_enum_value("TASK_RUNNING", TASK_RUNNING)
+		ctf_enum_value("TASK_INTERRUPTIBLE", TASK_INTERRUPTIBLE)
+		ctf_enum_value("TASK_UNINTERRUPTIBLE", TASK_UNINTERRUPTIBLE)
+		ctf_enum_value("TASK_STOPPED", __TASK_STOPPED)
+		ctf_enum_value("TASK_TRACED", __TASK_TRACED)
+		ctf_enum_value("EXIT_DEAD", EXIT_DEAD)
+		ctf_enum_value("EXIT_ZOMBIE", EXIT_ZOMBIE)
+
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,9,0))
+		ctf_enum_value("TASK_PARKED", TASK_PARKED)
+#endif /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,9,0)) */
+
+		ctf_enum_value("TASK_DEAD", TASK_DEAD)
+		ctf_enum_value("TASK_WAKEKILL", TASK_WAKEKILL)
+		ctf_enum_value("TASK_WAKING", TASK_WAKING)
+
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,2,0))
+		ctf_enum_value("TASK_NOLOAD", TASK_NOLOAD)
+#endif /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,2,0)) */
+
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,8,0))
+		ctf_enum_value("TASK_NEW", TASK_NEW)
+#endif /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,8,0)) */
+
+		ctf_enum_value("TASK_STATE_MAX", TASK_STATE_MAX)
+	)
+)
+
 /*
  * Tracepoint for calling kthread_stop, performed to end a kthread:
  */
@@ -202,7 +231,7 @@ LTTNG_TRACEPOINT_EVENT(sched_kthread_stop_ret,
 /*
  * Tracepoint for waking up a task:
  */
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0) || \
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0) || \
 	LTTNG_RT_KERNEL_RANGE(4,1,10,11, 4,2,0,0) || \
 	LTTNG_RT_KERNEL_RANGE(3,18,27,26, 3,19,0,0) || \
 	LTTNG_RT_KERNEL_RANGE(3,14,61,63, 3,15,0,0) || \
@@ -223,32 +252,24 @@ LTTNG_TRACEPOINT_EVENT_CLASS(sched_wakeup_template,
 		ctf_integer(int, target_cpu, task_cpu(p))
 	)
 )
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0)) */
 LTTNG_TRACEPOINT_EVENT_CLASS(sched_wakeup_template,
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35))
 	TP_PROTO(struct task_struct *p, int success),
 
 	TP_ARGS(p, success),
-#else
-	TP_PROTO(struct rq *rq, struct task_struct *p, int success),
-
-	TP_ARGS(rq, p, success),
-#endif
 
 	TP_FIELDS(
 		ctf_array_text(char, comm, p->comm, TASK_COMM_LEN)
 		ctf_integer(pid_t, tid, p->pid)
 		ctf_integer(int, prio, p->prio - MAX_RT_PRIO)
 		ctf_integer(int, success, success)
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,32))
 		ctf_integer(int, target_cpu, task_cpu(p))
-#endif
 	)
 )
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0)) */
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0) || \
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0) || \
 	LTTNG_RT_KERNEL_RANGE(4,1,10,11, 4,2,0,0) || \
 	LTTNG_RT_KERNEL_RANGE(3,18,27,26, 3,19,0,0) || \
 	LTTNG_RT_KERNEL_RANGE(3,14,61,63, 3,15,0,0) || \
@@ -280,7 +301,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(sched_wakeup_template, sched_wakeup_new,
 	     TP_PROTO(struct task_struct *p),
 	     TP_ARGS(p))
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35))
+#else
 
 LTTNG_TRACEPOINT_EVENT_INSTANCE(sched_wakeup_template, sched_wakeup,
 	     TP_PROTO(struct task_struct *p, int success),
@@ -293,54 +314,34 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(sched_wakeup_template, sched_wakeup_new,
 	     TP_PROTO(struct task_struct *p, int success),
 	     TP_ARGS(p, success))
 
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35)) */
-
-LTTNG_TRACEPOINT_EVENT_INSTANCE(sched_wakeup_template, sched_wakeup,
-	     TP_PROTO(struct rq *rq, struct task_struct *p, int success),
-	     TP_ARGS(rq, p, success))
-
-/*
- * Tracepoint for waking up a new task:
- */
-LTTNG_TRACEPOINT_EVENT_INSTANCE(sched_wakeup_template, sched_wakeup_new,
-	     TP_PROTO(struct rq *rq, struct task_struct *p, int success),
-	     TP_ARGS(rq, p, success))
-
-#endif /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35)) */
+#endif /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0)) */
 
 /*
  * Tracepoint for task switches, performed by the scheduler:
  */
 LTTNG_TRACEPOINT_EVENT(sched_switch,
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,4,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,4,0))
 	TP_PROTO(bool preempt,
 		 struct task_struct *prev,
 		 struct task_struct *next),
 
 	TP_ARGS(preempt, prev, next),
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35))
+#else
 	TP_PROTO(struct task_struct *prev,
 		 struct task_struct *next),
 
 	TP_ARGS(prev, next),
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35)) */
-	TP_PROTO(struct rq *rq, struct task_struct *prev,
-		 struct task_struct *next),
-
-	TP_ARGS(rq, prev, next),
-#endif /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35)) */
+#endif /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,4,0)) */
 
 	TP_FIELDS(
 		ctf_array_text(char, prev_comm,	prev->comm, TASK_COMM_LEN)
 		ctf_integer(pid_t, prev_tid, prev->pid)
 		ctf_integer(int, prev_prio, prev->prio - MAX_RT_PRIO)
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,4,0))
-		ctf_integer(long, prev_state, __trace_sched_switch_state(preempt, prev))
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35))
-		ctf_integer(long, prev_state, __trace_sched_switch_state(prev))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,4,0))
+		ctf_enum(task_state, long, prev_state, __trace_sched_switch_state(preempt, prev))
 #else
-		ctf_integer(long, prev_state, prev->state)
+		ctf_enum(task_state, long, prev_state, __trace_sched_switch_state(prev))
 #endif
 		ctf_array_text(char, next_comm, next->comm, TASK_COMM_LEN)
 		ctf_integer(pid_t, next_tid, next->pid)
@@ -397,15 +398,9 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(sched_process_template, sched_process_exit,
 /*
  * Tracepoint for waiting on task to unschedule:
  */
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35))
 LTTNG_TRACEPOINT_EVENT_INSTANCE(sched_process_template, sched_wait_task,
 	TP_PROTO(struct task_struct *p),
 	TP_ARGS(p))
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35)) */
-LTTNG_TRACEPOINT_EVENT_INSTANCE(sched_process_template, sched_wait_task,
-	TP_PROTO(struct rq *rq, struct task_struct *p),
-	TP_ARGS(rq, p))
-#endif /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35)) */
 
 /*
  * Tracepoint for a waiting task:
@@ -460,7 +455,7 @@ LTTNG_TRACEPOINT_EVENT_CODE(sched_process_fork,
 		ctf_array_text(char, parent_comm, parent->comm, TASK_COMM_LEN)
 		ctf_integer(pid_t, parent_tid, parent->pid)
 		ctf_integer(pid_t, parent_pid, parent->tgid)
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0))
 		ctf_integer(unsigned int, parent_ns_inum,
 			({
 				unsigned int parent_ns_inum = 0;
@@ -471,7 +466,7 @@ LTTNG_TRACEPOINT_EVENT_CODE(sched_process_fork,
 					pid_ns = task_active_pid_ns(parent);
 					if (pid_ns)
 						parent_ns_inum =
-							pid_ns->lttng_proc_inum;
+							pid_ns->lttng_ns_inum;
 				}
 				parent_ns_inum;
 			}))
@@ -480,7 +475,7 @@ LTTNG_TRACEPOINT_EVENT_CODE(sched_process_fork,
 		ctf_integer(pid_t, child_tid, child->pid)
 		ctf_sequence(pid_t, vtids, tp_locvar->vtids, u8, tp_locvar->ns_level)
 		ctf_integer(pid_t, child_pid, child->tgid)
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0))
 		ctf_integer(unsigned int, child_ns_inum,
 			({
 				unsigned int child_ns_inum = 0;
@@ -491,7 +486,7 @@ LTTNG_TRACEPOINT_EVENT_CODE(sched_process_fork,
 					pid_ns = task_active_pid_ns(child);
 					if (pid_ns)
 						child_ns_inum =
-							pid_ns->lttng_proc_inum;
+							pid_ns->lttng_ns_inum;
 				}
 				child_ns_inum;
 			}))
@@ -501,25 +496,7 @@ LTTNG_TRACEPOINT_EVENT_CODE(sched_process_fork,
 	TP_code_post()
 )
 
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(2,6,33))
-/*
- * Tracepoint for sending a signal:
- */
-LTTNG_TRACEPOINT_EVENT(sched_signal_send,
-
-	TP_PROTO(int sig, struct task_struct *p),
-
-	TP_ARGS(sig, p),
-
-	TP_FIELDS(
-		ctf_integer(int, sig, sig)
-		ctf_array_text(char, comm, p->comm, TASK_COMM_LEN)
-		ctf_integer(pid_t, tid, p->pid)
-	)
-)
-#endif
-
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,4,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,4,0))
 /*
  * Tracepoint for exec:
  */
@@ -538,7 +515,6 @@ LTTNG_TRACEPOINT_EVENT(sched_process_exec,
 )
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,32))
 /*
  * XXX the below sched_stat tracepoints only apply to SCHED_OTHER/BATCH/IDLE
  *     adding sched_stat support to SCHED_FIFO/RR would be welcome.
@@ -581,7 +557,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(sched_stat_template, sched_stat_iowait,
 	     TP_PROTO(struct task_struct *tsk, u64 delay),
 	     TP_ARGS(tsk, delay))
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
 /*
  * Tracepoint for accounting blocked time (time the task is in uninterruptible).
  */
@@ -607,9 +583,8 @@ LTTNG_TRACEPOINT_EVENT(sched_stat_runtime,
 		ctf_integer(u64, vruntime, vruntime)
 	)
 )
-#endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,12,0) || \
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,12,0) || \
 	LTTNG_RT_KERNEL_RANGE(4,9,27,18, 4,10,0,0) || \
 	LTTNG_RT_KERNEL_RANGE(4,11,5,1, 4,12,0,0))
 /*
@@ -629,7 +604,7 @@ LTTNG_TRACEPOINT_EVENT(sched_pi_setprio,
 		ctf_integer(int, newprio, pi_task ? pi_task->prio - MAX_RT_PRIO : tsk->prio - MAX_RT_PRIO)
 	)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,37))
+#else
 /*
  * Tracepoint for showing priority inheritance modifying a tasks
  * priority.
