@@ -30,7 +30,7 @@
 #include <linux/uaccess.h>
 #include <linux/slab.h>
 #include <linux/err.h>
-#include <wrapper/vmalloc.h>	/* for wrapper_vmalloc_sync_mappings() */
+#include <wrapper/vmalloc.h>	/* for wrapper_vmalloc_sync_all() */
 #include <wrapper/ringbuffer/vfs.h>
 #include <wrapper/ringbuffer/backend.h>
 #include <wrapper/ringbuffer/frontend.h>
@@ -52,7 +52,7 @@
 
 static struct proc_dir_entry *lttng_proc_dentry;
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,6,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(5,6,0))
 static const struct proc_ops lttng_proc_ops;
 #else
 static const struct file_operations lttng_proc_ops;
@@ -65,7 +65,6 @@ static const struct file_operations lttng_event_fops;
 static struct file_operations lttng_stream_ring_buffer_file_operations;
 
 static int put_u64(uint64_t val, unsigned long arg);
-static int put_u32(uint32_t val, unsigned long arg);
 
 /*
  * Teardown management: opened file descriptors keep a refcount on the module,
@@ -243,6 +242,44 @@ long lttng_abi_add_context(struct file *file,
 	case LTTNG_KERNEL_CONTEXT_CALLSTACK_KERNEL:
 	case LTTNG_KERNEL_CONTEXT_CALLSTACK_USER:
 		return lttng_add_callstack_to_ctx(ctx, context_param->ctx);
+	case LTTNG_KERNEL_CONTEXT_CGROUP_NS:
+		return lttng_add_cgroup_ns_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_IPC_NS:
+		return lttng_add_ipc_ns_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_MNT_NS:
+		return lttng_add_mnt_ns_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_NET_NS:
+		return lttng_add_net_ns_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_PID_NS:
+		return lttng_add_pid_ns_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_USER_NS:
+		return lttng_add_user_ns_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_UTS_NS:
+		return lttng_add_uts_ns_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_UID:
+		return lttng_add_uid_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_EUID:
+		return lttng_add_euid_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_SUID:
+		return lttng_add_suid_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_GID:
+		return lttng_add_gid_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_EGID:
+		return lttng_add_egid_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_SGID:
+		return lttng_add_sgid_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_VUID:
+		return lttng_add_vuid_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_VEUID:
+		return lttng_add_veuid_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_VSUID:
+		return lttng_add_vsuid_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_VGID:
+		return lttng_add_vgid_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_VEGID:
+		return lttng_add_vegid_to_ctx(ctx);
+	case LTTNG_KERNEL_CONTEXT_VSGID:
+		return lttng_add_vsgid_to_ctx(ctx);
 	default:
 		return -EINVAL;
 	}
@@ -360,7 +397,7 @@ long lttng_ioctl(struct file *file, unsigned int cmd, unsigned long arg)
 	}
 }
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,6,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(5,6,0))
 static const struct proc_ops lttng_proc_ops = {
 	.proc_ioctl = lttng_ioctl,
 #ifdef CONFIG_COMPAT
@@ -503,6 +540,27 @@ int lttng_abi_session_set_creation_time(struct lttng_session *session,
 	return 0;
 }
 
+static
+enum tracker_type get_tracker_type(struct lttng_kernel_tracker_args *tracker)
+{
+	switch (tracker->type) {
+	case LTTNG_KERNEL_TRACKER_PID:
+		return TRACKER_PID;
+	case LTTNG_KERNEL_TRACKER_VPID:
+		return TRACKER_VPID;
+	case LTTNG_KERNEL_TRACKER_UID:
+		return TRACKER_UID;
+	case LTTNG_KERNEL_TRACKER_VUID:
+		return TRACKER_VUID;
+	case LTTNG_KERNEL_TRACKER_GID:
+		return TRACKER_GID;
+	case LTTNG_KERNEL_TRACKER_VGID:
+		return TRACKER_VGID;
+	default:
+		return TRACKER_UNKNOWN;
+	}
+}
+
 /**
  *	lttng_session_ioctl - lttng session fd ioctl
  *
@@ -520,9 +578,13 @@ int lttng_abi_session_set_creation_time(struct lttng_session *session,
  *	LTTNG_KERNEL_METADATA
  *		Returns a LTTng metadata file descriptor
  *	LTTNG_KERNEL_SESSION_TRACK_PID
- *		Add PID to session tracker
+ *		Add PID to session PID tracker
  *	LTTNG_KERNEL_SESSION_UNTRACK_PID
- *		Remove PID from session tracker
+ *		Remove PID from session PID tracker
+ *	LTTNG_KERNEL_SESSION_TRACK_ID
+ *		Add ID to tracker
+ *	LTTNG_KERNEL_SESSION_UNTRACK_ID
+ *		Remove ID from tracker
  *
  * The returned channel will be deleted when its file descriptor is closed.
  */
@@ -595,11 +657,54 @@ long lttng_session_ioctl(struct file *file, unsigned int cmd, unsigned long arg)
 				METADATA_CHANNEL);
 	}
 	case LTTNG_KERNEL_SESSION_TRACK_PID:
-		return lttng_session_track_pid(session, (int) arg);
+		return lttng_session_track_id(session, TRACKER_PID, (int) arg);
 	case LTTNG_KERNEL_SESSION_UNTRACK_PID:
-		return lttng_session_untrack_pid(session, (int) arg);
+		return lttng_session_untrack_id(session, TRACKER_PID, (int) arg);
+	case LTTNG_KERNEL_SESSION_TRACK_ID:
+	{
+		struct lttng_kernel_tracker_args tracker;
+		enum tracker_type tracker_type;
+
+		if (copy_from_user(&tracker,
+				(struct lttng_kernel_tracker_args __user *) arg,
+				sizeof(struct lttng_kernel_tracker_args)))
+			return -EFAULT;
+		tracker_type = get_tracker_type(&tracker);
+		if (tracker_type == TRACKER_UNKNOWN)
+			return -EINVAL;
+		return lttng_session_track_id(session, tracker_type, tracker.id);
+	}
+	case LTTNG_KERNEL_SESSION_UNTRACK_ID:
+	{
+		struct lttng_kernel_tracker_args tracker;
+		enum tracker_type tracker_type;
+
+		if (copy_from_user(&tracker,
+				(struct lttng_kernel_tracker_args __user *) arg,
+				sizeof(struct lttng_kernel_tracker_args)))
+			return -EFAULT;
+		tracker_type = get_tracker_type(&tracker);
+		if (tracker_type == TRACKER_UNKNOWN)
+			return -EINVAL;
+		return lttng_session_untrack_id(session, tracker_type,
+				tracker.id);
+	}
 	case LTTNG_KERNEL_SESSION_LIST_TRACKER_PIDS:
-		return lttng_session_list_tracker_pids(session);
+		return lttng_session_list_tracker_ids(session, TRACKER_PID);
+	case LTTNG_KERNEL_SESSION_LIST_TRACKER_IDS:
+	{
+		struct lttng_kernel_tracker_args tracker;
+		enum tracker_type tracker_type;
+
+		if (copy_from_user(&tracker,
+				(struct lttng_kernel_tracker_args __user *) arg,
+				sizeof(struct lttng_kernel_tracker_args)))
+			return -EFAULT;
+		tracker_type = get_tracker_type(&tracker);
+		if (tracker_type == TRACKER_UNKNOWN)
+			return -EINVAL;
+		return lttng_session_list_tracker_ids(session, tracker_type);
+	}
 	case LTTNG_KERNEL_SESSION_METADATA_REGEN:
 		return lttng_session_metadata_regenerate(session);
 	case LTTNG_KERNEL_SESSION_STATEDUMP:
@@ -745,13 +850,6 @@ long lttng_metadata_ring_buffer_ioctl(struct file *filp,
 	int ret;
 	struct lttng_metadata_stream *stream = filp->private_data;
 	struct lib_ring_buffer *buf = stream->priv;
-	unsigned int rb_cmd;
-	bool coherent;
-
-	if (cmd == RING_BUFFER_GET_NEXT_SUBBUF_METADATA_CHECK)
-		rb_cmd = RING_BUFFER_GET_NEXT_SUBBUF;
-	else
-		rb_cmd = cmd;
 
 	switch (cmd) {
 	case RING_BUFFER_GET_NEXT_SUBBUF:
@@ -760,7 +858,7 @@ long lttng_metadata_ring_buffer_ioctl(struct file *filp,
 		struct lib_ring_buffer *buf = stream->priv;
 		struct channel *chan = buf->backend.chan;
 
-		ret = lttng_metadata_output_channel(stream, chan, NULL);
+		ret = lttng_metadata_output_channel(stream, chan);
 		if (ret > 0) {
 			lib_ring_buffer_switch_slow(buf, SWITCH_ACTIVE);
 			ret = 0;
@@ -786,7 +884,7 @@ long lttng_metadata_ring_buffer_ioctl(struct file *filp,
 		 * Before doing the actual ring buffer flush, write up to one
 		 * packet of metadata in the ring buffer.
 		 */
-		ret = lttng_metadata_output_channel(stream, chan, NULL);
+		ret = lttng_metadata_output_channel(stream, chan);
 		if (ret < 0)
 			goto err;
 		break;
@@ -803,28 +901,13 @@ long lttng_metadata_ring_buffer_ioctl(struct file *filp,
 
 		return lttng_metadata_cache_dump(stream);
 	}
-	case RING_BUFFER_GET_NEXT_SUBBUF_METADATA_CHECK:
-	{
-		struct lttng_metadata_stream *stream = filp->private_data;
-		struct lib_ring_buffer *buf = stream->priv;
-		struct channel *chan = buf->backend.chan;
-
-		ret = lttng_metadata_output_channel(stream, chan, &coherent);
-		if (ret > 0) {
-			lib_ring_buffer_switch_slow(buf, SWITCH_ACTIVE);
-			ret = 0;
-		} else if (ret < 0) {
-			goto err;
-		}
-		break;
-	}
 	default:
 		break;
 	}
 	/* PUT_SUBBUF is the one from lib ring buffer, unmodified. */
 
 	/* Performing lib ring buffer ioctl after our own. */
-	ret = lib_ring_buffer_ioctl(filp, rb_cmd, arg, buf);
+	ret = lib_ring_buffer_ioctl(filp, cmd, arg, buf);
 	if (ret < 0)
 		goto err;
 
@@ -835,10 +918,6 @@ long lttng_metadata_ring_buffer_ioctl(struct file *filp,
 				cmd, arg);
 		break;
 	}
-	case RING_BUFFER_GET_NEXT_SUBBUF_METADATA_CHECK:
-	{
-		return put_u32(coherent, arg);
-	}
 	default:
 		break;
 	}
@@ -854,13 +933,6 @@ long lttng_metadata_ring_buffer_compat_ioctl(struct file *filp,
 	int ret;
 	struct lttng_metadata_stream *stream = filp->private_data;
 	struct lib_ring_buffer *buf = stream->priv;
-	unsigned int rb_cmd;
-	bool coherent;
-
-	if (cmd == RING_BUFFER_GET_NEXT_SUBBUF_METADATA_CHECK)
-		rb_cmd = RING_BUFFER_GET_NEXT_SUBBUF;
-	else
-		rb_cmd = cmd;
 
 	switch (cmd) {
 	case RING_BUFFER_GET_NEXT_SUBBUF:
@@ -869,7 +941,7 @@ long lttng_metadata_ring_buffer_compat_ioctl(struct file *filp,
 		struct lib_ring_buffer *buf = stream->priv;
 		struct channel *chan = buf->backend.chan;
 
-		ret = lttng_metadata_output_channel(stream, chan, NULL);
+		ret = lttng_metadata_output_channel(stream, chan);
 		if (ret > 0) {
 			lib_ring_buffer_switch_slow(buf, SWITCH_ACTIVE);
 			ret = 0;
@@ -895,7 +967,7 @@ long lttng_metadata_ring_buffer_compat_ioctl(struct file *filp,
 		 * Before doing the actual ring buffer flush, write up to one
 		 * packet of metadata in the ring buffer.
 		 */
-		ret = lttng_metadata_output_channel(stream, chan, NULL);
+		ret = lttng_metadata_output_channel(stream, chan);
 		if (ret < 0)
 			goto err;
 		break;
@@ -912,28 +984,13 @@ long lttng_metadata_ring_buffer_compat_ioctl(struct file *filp,
 
 		return lttng_metadata_cache_dump(stream);
 	}
-	case RING_BUFFER_GET_NEXT_SUBBUF_METADATA_CHECK:
-	{
-		struct lttng_metadata_stream *stream = filp->private_data;
-		struct lib_ring_buffer *buf = stream->priv;
-		struct channel *chan = buf->backend.chan;
-
-		ret = lttng_metadata_output_channel(stream, chan, &coherent);
-		if (ret > 0) {
-			lib_ring_buffer_switch_slow(buf, SWITCH_ACTIVE);
-			ret = 0;
-		} else if (ret < 0) {
-			goto err;
-		}
-		break;
-	}
 	default:
 		break;
 	}
 	/* PUT_SUBBUF is the one from lib ring buffer, unmodified. */
 
 	/* Performing lib ring buffer ioctl after our own. */
-	ret = lib_ring_buffer_compat_ioctl(filp, rb_cmd, arg, buf);
+	ret = lib_ring_buffer_compat_ioctl(filp, cmd, arg, buf);
 	if (ret < 0)
 		goto err;
 
@@ -944,10 +1001,6 @@ long lttng_metadata_ring_buffer_compat_ioctl(struct file *filp,
 				cmd, arg);
 		break;
 	}
-	case RING_BUFFER_GET_NEXT_SUBBUF_METADATA_CHECK:
-	{
-		return put_u32(coherent, arg);
-	}
 	default:
 		break;
 	}
@@ -984,12 +1037,8 @@ int lttng_metadata_ring_buffer_release(struct inode *inode, struct file *file)
 	struct lttng_metadata_stream *stream = file->private_data;
 	struct lib_ring_buffer *buf = stream->priv;
 
-	mutex_lock(&stream->metadata_cache->lock);
-	list_del(&stream->list);
-	mutex_unlock(&stream->metadata_cache->lock);
 	kref_put(&stream->metadata_cache->refcount, metadata_cache_destroy);
 	module_put(stream->transport->owner);
-	kfree(stream);
 	return lib_ring_buffer_release(inode, file, buf);
 }
 
@@ -1118,8 +1167,6 @@ int lttng_abi_open_metadata_stream(struct file *channel_file)
 	metadata_stream->priv = buf;
 	stream_priv = metadata_stream;
 	metadata_stream->transport = channel->transport;
-	/* Initial state is an empty metadata, considered as incoherent. */
-	metadata_stream->coherent = false;
 
 	/*
 	 * Since life-time of metadata cache differs from that of
@@ -1141,10 +1188,8 @@ int lttng_abi_open_metadata_stream(struct file *channel_file)
 	if (ret < 0)
 		goto fd_error;
 
-	mutex_lock(&session->metadata_cache->lock);
 	list_add(&metadata_stream->list,
 		&session->metadata_cache->metadata_stream);
-	mutex_unlock(&session->metadata_cache->lock);
 	return ret;
 
 fd_error:
@@ -1158,46 +1203,6 @@ nomem:
 	return ret;
 }
 
-static
-int lttng_abi_validate_event_param(struct lttng_kernel_event *event_param)
-{
-	/* Limit ABI to implemented features. */
-	switch (event_param->instrumentation) {
-	case LTTNG_KERNEL_SYSCALL:
-		switch (event_param->u.syscall.entryexit) {
-		case LTTNG_KERNEL_SYSCALL_ENTRYEXIT:
-			break;
-		default:
-			return -EINVAL;
-		}
-		switch (event_param->u.syscall.abi) {
-		case LTTNG_KERNEL_SYSCALL_ABI_ALL:
-			break;
-		default:
-			return -EINVAL;
-		}
-		switch (event_param->u.syscall.match) {
-		case LTTNG_SYSCALL_MATCH_NAME:
-			break;
-		default:
-			return -EINVAL;
-		}
-		break;
-
-	case LTTNG_KERNEL_TRACEPOINT:	/* Fallthrough */
-	case LTTNG_KERNEL_KPROBE:	/* Fallthrough */
-	case LTTNG_KERNEL_KRETPROBE:	/* Fallthrough */
-	case LTTNG_KERNEL_NOOP:		/* Fallthrough */
-	case LTTNG_KERNEL_UPROBE:
-		break;
-
-	case LTTNG_KERNEL_FUNCTION:	/* Fallthrough */
-	default:
-		return -EINVAL;
-	}
-	return 0;
-}
-
 static
 int lttng_abi_create_event(struct file *channel_file,
 			   struct lttng_kernel_event *event_param)
@@ -1239,9 +1244,6 @@ int lttng_abi_create_event(struct file *channel_file,
 		ret = -EOVERFLOW;
 		goto refcount_error;
 	}
-	ret = lttng_abi_validate_event_param(event_param);
-	if (ret)
-		goto event_error;
 	if (event_param->instrumentation == LTTNG_KERNEL_TRACEPOINT
 			|| event_param->instrumentation == LTTNG_KERNEL_SYSCALL) {
 		struct lttng_enabler *enabler;
@@ -1701,11 +1703,6 @@ static int put_u64(uint64_t val, unsigned long arg)
 	return put_user(val, (uint64_t __user *) arg);
 }
 
-static int put_u32(uint32_t val, unsigned long arg)
-{
-	return put_user(val, (uint32_t __user *) arg);
-}
-
 static long lttng_stream_ring_buffer_ioctl(struct file *filp,
 		unsigned int cmd, unsigned long arg)
 {
@@ -1941,7 +1938,7 @@ int __init lttng_abi_init(void)
 {
 	int ret = 0;
 
-	wrapper_vmalloc_sync_mappings();
+	wrapper_vmalloc_sync_all();
 	lttng_clock_ref();
 
 	ret = lttng_tp_mempool_init();
