@@ -28,9 +28,9 @@
 #include <linux/uaccess.h>
 #include <linux/vmalloc.h>
 #include <linux/uuid.h>
+#include <linux/dmi.h>
 
-#include <wrapper/uuid.h>
-#include <wrapper/vmalloc.h>	/* for wrapper_vmalloc_sync_mappings() */
+#include <wrapper/vmalloc.h>	/* for wrapper_vmalloc_sync_all() */
 #include <wrapper/random.h>
 #include <wrapper/tracepoint.h>
 #include <wrapper/list.h>
@@ -41,7 +41,6 @@
 #include <lttng-abi-old.h>
 #include <lttng-endian.h>
 #include <lttng-string-utils.h>
-#include <wrapper/vzalloc.h>
 #include <wrapper/ringbuffer/backend.h>
 #include <wrapper/ringbuffer/frontend.h>
 #include <wrapper/time.h>
@@ -78,22 +77,21 @@ int _lttng_field_statedump(struct lttng_session *session,
 
 void synchronize_trace(void)
 {
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,1,0) || \
-	LTTNG_RHEL_KERNEL_RANGE(4,18,0,193,0,0, 4,19,0,0,0,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(5,1,0))
 	synchronize_rcu();
 #else
 	synchronize_sched();
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,4,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,4,0))
 #ifdef CONFIG_PREEMPT_RT_FULL
 	synchronize_rcu();
 #endif
-#else /* (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,4,0)) */
+#else /* (LINUX_VERSION_CODE >= KERNEL_VERSION(3,4,0)) */
 #ifdef CONFIG_PREEMPT_RT
 	synchronize_rcu();
 #endif
-#endif /* (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,4,0)) */
+#endif /* (LINUX_VERSION_CODE >= KERNEL_VERSION(3,4,0)) */
 }
 
 void lttng_lock_sessions(void)
@@ -132,13 +130,13 @@ struct lttng_session *lttng_session_create(void)
 		goto err;
 	INIT_LIST_HEAD(&session->chan);
 	INIT_LIST_HEAD(&session->events);
-	lttng_guid_gen(&session->uuid);
+	uuid_le_gen(&session->uuid);
 
 	metadata_cache = kzalloc(sizeof(struct lttng_metadata_cache),
 			GFP_KERNEL);
 	if (!metadata_cache)
 		goto err_free_session;
-	metadata_cache->data = lttng_vzalloc(METADATA_CACHE_DEFAULT_SIZE);
+	metadata_cache->data = vzalloc(METADATA_CACHE_DEFAULT_SIZE);
 	if (!metadata_cache->data)
 		goto err_free_cache;
 	metadata_cache->cache_alloc = METADATA_CACHE_DEFAULT_SIZE;
@@ -152,6 +150,18 @@ struct lttng_session *lttng_session_create(void)
 	for (i = 0; i < LTTNG_EVENT_HT_SIZE; i++)
 		INIT_HLIST_HEAD(&session->events_ht.table[i]);
 	list_add(&session->list, &sessions);
+	session->pid_tracker.session = session;
+	session->pid_tracker.tracker_type = TRACKER_PID;
+	session->vpid_tracker.session = session;
+	session->vpid_tracker.tracker_type = TRACKER_VPID;
+	session->uid_tracker.session = session;
+	session->uid_tracker.tracker_type = TRACKER_UID;
+	session->vuid_tracker.session = session;
+	session->vuid_tracker.tracker_type = TRACKER_VUID;
+	session->gid_tracker.session = session;
+	session->gid_tracker.tracker_type = TRACKER_GID;
+	session->vgid_tracker.session = session;
+	session->vgid_tracker.tracker_type = TRACKER_VGID;
 	mutex_unlock(&sessions_mutex);
 	return session;
 
@@ -191,10 +201,6 @@ void lttng_session_destroy(struct lttng_session *session)
 		WARN_ON(ret);
 	}
 	synchronize_trace();	/* Wait for in-flight events to complete */
-	list_for_each_entry(chan, &session->chan, list) {
-		ret = lttng_syscalls_destroy(chan);
-		WARN_ON(ret);
-	}
 	list_for_each_entry_safe(enabler, tmpenabler,
 			&session->enablers_head, node)
 		lttng_enabler_destroy(enabler);
@@ -204,12 +210,14 @@ void lttng_session_destroy(struct lttng_session *session)
 		BUG_ON(chan->channel_type == METADATA_CHANNEL);
 		_lttng_channel_destroy(chan);
 	}
-	mutex_lock(&session->metadata_cache->lock);
 	list_for_each_entry(metadata_stream, &session->metadata_cache->metadata_stream, list)
 		_lttng_metadata_channel_hangup(metadata_stream);
-	mutex_unlock(&session->metadata_cache->lock);
-	if (session->pid_tracker)
-		lttng_pid_tracker_destroy(session->pid_tracker);
+	lttng_id_tracker_destroy(&session->pid_tracker, false);
+	lttng_id_tracker_destroy(&session->vpid_tracker, false);
+	lttng_id_tracker_destroy(&session->uid_tracker, false);
+	lttng_id_tracker_destroy(&session->vuid_tracker, false);
+	lttng_id_tracker_destroy(&session->gid_tracker, false);
+	lttng_id_tracker_destroy(&session->vgid_tracker, false);
 	kref_put(&session->metadata_cache->refcount, metadata_cache_destroy);
 	list_del(&session->list);
 	mutex_unlock(&sessions_mutex);
@@ -240,6 +248,9 @@ int lttng_session_enable(struct lttng_session *session)
 	/* Set transient enabler state to "enabled" */
 	session->tstate = 1;
 
+	/* We need to sync enablers with session before activation. */
+	lttng_session_sync_enablers(session);
+
 	/*
 	 * Snapshot the number of events per channel to know the type of header
 	 * we need to use.
@@ -253,9 +264,6 @@ int lttng_session_enable(struct lttng_session *session)
 			chan->header_type = 2;	/* large */
 	}
 
-	/* We need to sync enablers with session before activation. */
-	lttng_session_sync_enablers(session);
-
 	/* Clear each stream's quiescent state. */
 	list_for_each_entry(chan, &session->chan, list) {
 		if (chan->channel_type != METADATA_CHANNEL)
@@ -690,8 +698,6 @@ struct lttng_event *_lttng_event_create(struct lttng_channel *chan,
 		event_return->enabled = 0;
 		event_return->registered = 1;
 		event_return->instrumentation = itype;
-		INIT_LIST_HEAD(&event_return->bytecode_runtime_head);
-		INIT_LIST_HEAD(&event_return->enablers_ref_head);
 		/*
 		 * Populate lttng_event structure before kretprobe registration.
 		 */
@@ -732,28 +738,6 @@ struct lttng_event *_lttng_event_create(struct lttng_channel *chan,
 		event->enabled = 0;
 		event->registered = 0;
 		event->desc = event_desc;
-		switch (event_param->u.syscall.entryexit) {
-		case LTTNG_KERNEL_SYSCALL_ENTRYEXIT:
-			ret = -EINVAL;
-			goto register_error;
-		case LTTNG_KERNEL_SYSCALL_ENTRY:
-			event->u.syscall.entryexit = LTTNG_SYSCALL_ENTRY;
-			break;
-		case LTTNG_KERNEL_SYSCALL_EXIT:
-			event->u.syscall.entryexit = LTTNG_SYSCALL_EXIT;
-			break;
-		}
-		switch (event_param->u.syscall.abi) {
-		case LTTNG_KERNEL_SYSCALL_ABI_ALL:
-			ret = -EINVAL;
-			goto register_error;
-		case LTTNG_KERNEL_SYSCALL_ABI_NATIVE:
-			event->u.syscall.abi = LTTNG_SYSCALL_ABI_NATIVE;
-			break;
-		case LTTNG_KERNEL_SYSCALL_ABI_COMPAT:
-			event->u.syscall.abi = LTTNG_SYSCALL_ABI_COMPAT;
-			break;
-		}
 		if (!event->desc) {
 			ret = -EINVAL;
 			goto register_error;
@@ -840,7 +824,8 @@ void register_event(struct lttng_event *event)
 						  event);
 		break;
 	case LTTNG_KERNEL_SYSCALL:
-		ret = lttng_syscall_filter_enable(event->chan, event);
+		ret = lttng_syscall_filter_enable(event->chan,
+			desc->name);
 		break;
 	case LTTNG_KERNEL_KPROBE:
 	case LTTNG_KERNEL_UPROBE:
@@ -883,7 +868,8 @@ int _lttng_event_unregister(struct lttng_event *event)
 		ret = 0;
 		break;
 	case LTTNG_KERNEL_SYSCALL:
-		ret = lttng_syscall_filter_disable(event->chan, event);
+		ret = lttng_syscall_filter_disable(event->chan,
+			desc->name);
 		break;
 	case LTTNG_KERNEL_NOOP:
 		ret = 0;
@@ -907,8 +893,6 @@ int _lttng_event_unregister(struct lttng_event *event)
 static
 void _lttng_event_destroy(struct lttng_event *event)
 {
-	struct lttng_enabler_ref *enabler_ref, *tmp_enabler_ref;
-
 	switch (event->instrumentation) {
 	case LTTNG_KERNEL_TRACEPOINT:
 		lttng_event_put(event->desc);
@@ -934,99 +918,88 @@ void _lttng_event_destroy(struct lttng_event *event)
 	}
 	list_del(&event->list);
 	lttng_destroy_context(event->ctx);
-	lttng_free_event_filter_runtime(event);
-	/* Free event enabler refs */
-	list_for_each_entry_safe(enabler_ref, tmp_enabler_ref,
-				 &event->enablers_ref_head, node)
-		kfree(enabler_ref);
 	kmem_cache_free(event_cache, event);
 }
 
-int lttng_session_track_pid(struct lttng_session *session, int pid)
+struct lttng_id_tracker *get_tracker(struct lttng_session *session,
+		enum tracker_type tracker_type)
 {
+	switch (tracker_type) {
+	case TRACKER_PID:
+		return &session->pid_tracker;
+	case TRACKER_VPID:
+		return &session->vpid_tracker;
+	case TRACKER_UID:
+		return &session->uid_tracker;
+	case TRACKER_VUID:
+		return &session->vuid_tracker;
+	case TRACKER_GID:
+		return &session->gid_tracker;
+	case TRACKER_VGID:
+		return &session->vgid_tracker;
+	default:
+		WARN_ON_ONCE(1);
+		return NULL;
+	}
+}
+
+int lttng_session_track_id(struct lttng_session *session,
+		enum tracker_type tracker_type, int id)
+{
+	struct lttng_id_tracker *tracker;
 	int ret;
 
-	if (pid < -1)
+	tracker = get_tracker(session, tracker_type);
+	if (!tracker)
+		return -EINVAL;
+	if (id < -1)
 		return -EINVAL;
 	mutex_lock(&sessions_mutex);
-	if (pid == -1) {
-		/* track all pids: destroy tracker. */
-		if (session->pid_tracker) {
-			struct lttng_pid_tracker *lpf;
-
-			lpf = session->pid_tracker;
-			rcu_assign_pointer(session->pid_tracker, NULL);
-			synchronize_trace();
-			lttng_pid_tracker_destroy(lpf);
-		}
+	if (id == -1) {
+		/* track all ids: destroy tracker. */
+		lttng_id_tracker_destroy(tracker, true);
 		ret = 0;
 	} else {
-		if (!session->pid_tracker) {
-			struct lttng_pid_tracker *lpf;
-
-			lpf = lttng_pid_tracker_create();
-			if (!lpf) {
-				ret = -ENOMEM;
-				goto unlock;
-			}
-			ret = lttng_pid_tracker_add(lpf, pid);
-			rcu_assign_pointer(session->pid_tracker, lpf);
-		} else {
-			ret = lttng_pid_tracker_add(session->pid_tracker, pid);
-		}
+		ret = lttng_id_tracker_add(tracker, id);
 	}
-unlock:
 	mutex_unlock(&sessions_mutex);
 	return ret;
 }
 
-int lttng_session_untrack_pid(struct lttng_session *session, int pid)
+int lttng_session_untrack_id(struct lttng_session *session,
+		enum tracker_type tracker_type, int id)
 {
+	struct lttng_id_tracker *tracker;
 	int ret;
 
-	if (pid < -1)
+	tracker = get_tracker(session, tracker_type);
+	if (!tracker)
+		return -EINVAL;
+	if (id < -1)
 		return -EINVAL;
 	mutex_lock(&sessions_mutex);
-	if (pid == -1) {
-		/* untrack all pids: replace by empty tracker. */
-		struct lttng_pid_tracker *old_lpf = session->pid_tracker;
-		struct lttng_pid_tracker *lpf;
-
-		lpf = lttng_pid_tracker_create();
-		if (!lpf) {
-			ret = -ENOMEM;
-			goto unlock;
-		}
-		rcu_assign_pointer(session->pid_tracker, lpf);
-		synchronize_trace();
-		if (old_lpf)
-			lttng_pid_tracker_destroy(old_lpf);
-		ret = 0;
+	if (id == -1) {
+		/* untrack all ids: replace by empty tracker. */
+		ret = lttng_id_tracker_empty_set(tracker);
 	} else {
-		if (!session->pid_tracker) {
-			ret = -ENOENT;
-			goto unlock;
-		}
-		ret = lttng_pid_tracker_del(session->pid_tracker, pid);
+		ret = lttng_id_tracker_del(tracker, id);
 	}
-unlock:
 	mutex_unlock(&sessions_mutex);
 	return ret;
 }
 
 static
-void *pid_list_start(struct seq_file *m, loff_t *pos)
+void *id_list_start(struct seq_file *m, loff_t *pos)
 {
-	struct lttng_session *session = m->private;
-	struct lttng_pid_tracker *lpf;
-	struct lttng_pid_hash_node *e;
+	struct lttng_id_tracker *id_tracker = m->private;
+	struct lttng_id_tracker_rcu *id_tracker_p = id_tracker->p;
+	struct lttng_id_hash_node *e;
 	int iter = 0, i;
 
 	mutex_lock(&sessions_mutex);
-	lpf = session->pid_tracker;
-	if (lpf) {
-		for (i = 0; i < LTTNG_PID_TABLE_SIZE; i++) {
-			struct hlist_head *head = &lpf->pid_hash[i];
+	if (id_tracker_p) {
+		for (i = 0; i < LTTNG_ID_TABLE_SIZE; i++) {
+			struct hlist_head *head = &id_tracker_p->id_hash[i];
 
 			lttng_hlist_for_each_entry(e, head, hlist) {
 				if (iter++ >= *pos)
@@ -1034,9 +1007,9 @@ void *pid_list_start(struct seq_file *m, loff_t *pos)
 			}
 		}
 	} else {
-		/* PID tracker disabled. */
+		/* ID tracker disabled. */
 		if (iter >= *pos && iter == 0) {
-			return session;	/* empty tracker */
+			return id_tracker_p;	/* empty tracker */
 		}
 		iter++;
 	}
@@ -1046,18 +1019,17 @@ void *pid_list_start(struct seq_file *m, loff_t *pos)
 
 /* Called with sessions_mutex held. */
 static
-void *pid_list_next(struct seq_file *m, void *p, loff_t *ppos)
+void *id_list_next(struct seq_file *m, void *p, loff_t *ppos)
 {
-	struct lttng_session *session = m->private;
-	struct lttng_pid_tracker *lpf;
-	struct lttng_pid_hash_node *e;
+	struct lttng_id_tracker *id_tracker = m->private;
+	struct lttng_id_tracker_rcu *id_tracker_p = id_tracker->p;
+	struct lttng_id_hash_node *e;
 	int iter = 0, i;
 
 	(*ppos)++;
-	lpf = session->pid_tracker;
-	if (lpf) {
-		for (i = 0; i < LTTNG_PID_TABLE_SIZE; i++) {
-			struct hlist_head *head = &lpf->pid_hash[i];
+	if (id_tracker_p) {
+		for (i = 0; i < LTTNG_ID_TABLE_SIZE; i++) {
+			struct hlist_head *head = &id_tracker_p->id_hash[i];
 
 			lttng_hlist_for_each_entry(e, head, hlist) {
 				if (iter++ >= *ppos)
@@ -1065,9 +1037,9 @@ void *pid_list_next(struct seq_file *m, void *p, loff_t *ppos)
 			}
 		}
 	} else {
-		/* PID tracker disabled. */
+		/* ID tracker disabled. */
 		if (iter >= *ppos && iter == 0)
-			return session;	/* empty tracker */
+			return p;	/* empty tracker */
 		iter++;
 	}
 
@@ -1076,67 +1048,91 @@ void *pid_list_next(struct seq_file *m, void *p, loff_t *ppos)
 }
 
 static
-void pid_list_stop(struct seq_file *m, void *p)
+void id_list_stop(struct seq_file *m, void *p)
 {
 	mutex_unlock(&sessions_mutex);
 }
 
 static
-int pid_list_show(struct seq_file *m, void *p)
+int id_list_show(struct seq_file *m, void *p)
 {
-	int pid;
+	struct lttng_id_tracker *id_tracker = m->private;
+	struct lttng_id_tracker_rcu *id_tracker_p = id_tracker->p;
+	int id;
 
-	if (p == m->private) {
+	if (p == id_tracker_p) {
 		/* Tracker disabled. */
-		pid = -1;
+		id = -1;
 	} else {
-		const struct lttng_pid_hash_node *e = p;
+		const struct lttng_id_hash_node *e = p;
 
-		pid = lttng_pid_tracker_get_node_pid(e);
+		id = lttng_id_tracker_get_node_id(e);
+	}
+	switch (id_tracker->tracker_type) {
+	case TRACKER_PID:
+		seq_printf(m,	"process { pid = %d; };\n", id);
+		break;
+	case TRACKER_VPID:
+		seq_printf(m,	"process { vpid = %d; };\n", id);
+		break;
+	case TRACKER_UID:
+		seq_printf(m,	"user { uid = %d; };\n", id);
+		break;
+	case TRACKER_VUID:
+		seq_printf(m,	"user { vuid = %d; };\n", id);
+		break;
+	case TRACKER_GID:
+		seq_printf(m,	"group { gid = %d; };\n", id);
+		break;
+	case TRACKER_VGID:
+		seq_printf(m,	"group { vgid = %d; };\n", id);
+		break;
+	default:
+		seq_printf(m,	"UNKNOWN { field = %d };\n", id);
 	}
-	seq_printf(m,	"process { pid = %d; };\n", pid);
 	return 0;
 }
 
 static
-const struct seq_operations lttng_tracker_pids_list_seq_ops = {
-	.start = pid_list_start,
-	.next = pid_list_next,
-	.stop = pid_list_stop,
-	.show = pid_list_show,
+const struct seq_operations lttng_tracker_ids_list_seq_ops = {
+	.start = id_list_start,
+	.next = id_list_next,
+	.stop = id_list_stop,
+	.show = id_list_show,
 };
 
 static
-int lttng_tracker_pids_list_open(struct inode *inode, struct file *file)
+int lttng_tracker_ids_list_open(struct inode *inode, struct file *file)
 {
-	return seq_open(file, &lttng_tracker_pids_list_seq_ops);
+	return seq_open(file, &lttng_tracker_ids_list_seq_ops);
 }
 
 static
-int lttng_tracker_pids_list_release(struct inode *inode, struct file *file)
+int lttng_tracker_ids_list_release(struct inode *inode, struct file *file)
 {
 	struct seq_file *m = file->private_data;
-	struct lttng_session *session = m->private;
+	struct lttng_id_tracker *id_tracker = m->private;
 	int ret;
 
-	WARN_ON_ONCE(!session);
+	WARN_ON_ONCE(!id_tracker);
 	ret = seq_release(inode, file);
-	if (!ret && session)
-		fput(session->file);
+	if (!ret)
+		fput(id_tracker->session->file);
 	return ret;
 }
 
-const struct file_operations lttng_tracker_pids_list_fops = {
+const struct file_operations lttng_tracker_ids_list_fops = {
 	.owner = THIS_MODULE,
-	.open = lttng_tracker_pids_list_open,
+	.open = lttng_tracker_ids_list_open,
 	.read = seq_read,
 	.llseek = seq_lseek,
-	.release = lttng_tracker_pids_list_release,
+	.release = lttng_tracker_ids_list_release,
 };
 
-int lttng_session_list_tracker_pids(struct lttng_session *session)
+int lttng_session_list_tracker_ids(struct lttng_session *session,
+		enum tracker_type tracker_type)
 {
-	struct file *tracker_pids_list_file;
+	struct file *tracker_ids_list_file;
 	struct seq_file *m;
 	int file_fd, ret;
 
@@ -1146,30 +1142,32 @@ int lttng_session_list_tracker_pids(struct lttng_session *session)
 		goto fd_error;
 	}
 
-	tracker_pids_list_file = anon_inode_getfile("[lttng_tracker_pids_list]",
-					  &lttng_tracker_pids_list_fops,
+	tracker_ids_list_file = anon_inode_getfile("[lttng_tracker_ids_list]",
+					  &lttng_tracker_ids_list_fops,
 					  NULL, O_RDWR);
-	if (IS_ERR(tracker_pids_list_file)) {
-		ret = PTR_ERR(tracker_pids_list_file);
+	if (IS_ERR(tracker_ids_list_file)) {
+		ret = PTR_ERR(tracker_ids_list_file);
 		goto file_error;
 	}
 	if (!atomic_long_add_unless(&session->file->f_count, 1, LONG_MAX)) {
 		ret = -EOVERFLOW;
 		goto refcount_error;
 	}
-	ret = lttng_tracker_pids_list_fops.open(NULL, tracker_pids_list_file);
+	ret = lttng_tracker_ids_list_fops.open(NULL, tracker_ids_list_file);
 	if (ret < 0)
 		goto open_error;
-	m = tracker_pids_list_file->private_data;
-	m->private = session;
-	fd_install(file_fd, tracker_pids_list_file);
+	m = tracker_ids_list_file->private_data;
+
+	m->private = get_tracker(session, tracker_type);
+	BUG_ON(!m->private);
+	fd_install(file_fd, tracker_ids_list_file);
 
 	return file_fd;
 
 open_error:
 	atomic_long_dec(&session->file->f_count);
 refcount_error:
-	fput(tracker_pids_list_file);
+	fput(tracker_ids_list_file);
 file_error:
 	put_unused_fd(file_fd);
 fd_error:
@@ -1203,87 +1201,39 @@ int lttng_desc_match_enabler(const struct lttng_event_desc *desc,
 		struct lttng_enabler *enabler)
 {
 	const char *desc_name, *enabler_name;
-	bool compat = false, entry = false;
 
 	enabler_name = enabler->event_param.name;
 	switch (enabler->event_param.instrumentation) {
 	case LTTNG_KERNEL_TRACEPOINT:
 		desc_name = desc->name;
-		switch (enabler->type) {
-		case LTTNG_ENABLER_STAR_GLOB:
-			return lttng_match_enabler_star_glob(desc_name, enabler_name);
-		case LTTNG_ENABLER_NAME:
-			return lttng_match_enabler_name(desc_name, enabler_name);
-		default:
-			return -EINVAL;
-		}
 		break;
 	case LTTNG_KERNEL_SYSCALL:
 		desc_name = desc->name;
-		if (!strncmp(desc_name, "compat_", strlen("compat_"))) {
+		if (!strncmp(desc_name, "compat_", strlen("compat_")))
 			desc_name += strlen("compat_");
-			compat = true;
-		}
 		if (!strncmp(desc_name, "syscall_exit_",
 				strlen("syscall_exit_"))) {
 			desc_name += strlen("syscall_exit_");
 		} else if (!strncmp(desc_name, "syscall_entry_",
 				strlen("syscall_entry_"))) {
 			desc_name += strlen("syscall_entry_");
-			entry = true;
 		} else {
 			WARN_ON_ONCE(1);
 			return -EINVAL;
 		}
-		switch (enabler->event_param.u.syscall.entryexit) {
-		case LTTNG_KERNEL_SYSCALL_ENTRYEXIT:
-			break;
-		case LTTNG_KERNEL_SYSCALL_ENTRY:
-			if (!entry)
-				return 0;
-			break;
-		case LTTNG_KERNEL_SYSCALL_EXIT:
-			if (entry)
-				return 0;
-			break;
-		default:
-			return -EINVAL;
-		}
-		switch (enabler->event_param.u.syscall.abi) {
-		case LTTNG_KERNEL_SYSCALL_ABI_ALL:
-			break;
-		case LTTNG_KERNEL_SYSCALL_ABI_NATIVE:
-			if (compat)
-				return 0;
-			break;
-		case LTTNG_KERNEL_SYSCALL_ABI_COMPAT:
-			if (!compat)
-				return 0;
-			break;
-		default:
-			return -EINVAL;
-		}
-		switch (enabler->event_param.u.syscall.match) {
-		case LTTNG_SYSCALL_MATCH_NAME:
-			switch (enabler->type) {
-			case LTTNG_ENABLER_STAR_GLOB:
-				return lttng_match_enabler_star_glob(desc_name, enabler_name);
-			case LTTNG_ENABLER_NAME:
-				return lttng_match_enabler_name(desc_name, enabler_name);
-			default:
-				return -EINVAL;
-			}
-			break;
-		case LTTNG_SYSCALL_MATCH_NR:
-			return -EINVAL;	/* Not implemented. */
-		default:
-			return -EINVAL;
-		}
 		break;
 	default:
 		WARN_ON_ONCE(1);
 		return -EINVAL;
 	}
+	switch (enabler->type) {
+	case LTTNG_ENABLER_STAR_GLOB:
+		return lttng_match_enabler_star_glob(desc_name, enabler_name);
+	case LTTNG_ENABLER_NAME:
+		return lttng_match_enabler_name(desc_name, enabler_name);
+	default:
+		return -EINVAL;
+	}
 }
 
 static
@@ -1409,21 +1359,9 @@ void lttng_create_event_if_missing(struct lttng_enabler *enabler)
 static
 int lttng_enabler_ref_events(struct lttng_enabler *enabler)
 {
-	struct lttng_channel *chan = enabler->chan;
-	struct lttng_session *session = chan->session;
+	struct lttng_session *session = enabler->chan->session;
 	struct lttng_event *event;
 
-	if (enabler->event_param.instrumentation == LTTNG_KERNEL_SYSCALL &&
-			enabler->event_param.u.syscall.entryexit == LTTNG_KERNEL_SYSCALL_ENTRYEXIT &&
-			enabler->event_param.u.syscall.abi == LTTNG_KERNEL_SYSCALL_ABI_ALL &&
-			enabler->event_param.u.syscall.match == LTTNG_SYSCALL_MATCH_NAME &&
-			!strcmp(enabler->event_param.name, "*")) {
-		if (enabler->enabled)
-			WRITE_ONCE(chan->syscall_all, 1);
-		else
-			WRITE_ONCE(chan->syscall_all, 0);
-	}
-
 	/* First ensure that probe events are created for this enabler. */
 	lttng_create_event_if_missing(enabler);
 
@@ -1684,7 +1622,7 @@ void lttng_session_lazy_sync_enablers(struct lttng_session *session)
  * was written and a negative value on error.
  */
 int lttng_metadata_output_channel(struct lttng_metadata_stream *stream,
-		struct channel *chan, bool *coherent)
+		struct channel *chan)
 {
 	struct lib_ring_buffer_ctx ctx;
 	int ret = 0;
@@ -1723,7 +1661,6 @@ int lttng_metadata_output_channel(struct lttng_metadata_stream *stream,
 	ret = stream->transport->ops.event_reserve(&ctx, 0);
 	if (ret != 0) {
 		printk(KERN_WARNING "LTTng: Metadata event reservation failed\n");
-		stream->coherent = false;
 		goto end;
 	}
 	stream->transport->ops.event_write(&ctx,
@@ -1731,46 +1668,18 @@ int lttng_metadata_output_channel(struct lttng_metadata_stream *stream,
 			reserve_len);
 	stream->transport->ops.event_commit(&ctx);
 	stream->metadata_in += reserve_len;
-	if (reserve_len < len)
-		stream->coherent = false;
-	else
-		stream->coherent = true;
 	ret = reserve_len;
 
 end:
-	if (coherent)
-		*coherent = stream->coherent;
 	mutex_unlock(&stream->metadata_cache->lock);
 	return ret;
 }
 
-static
-void lttng_metadata_begin(struct lttng_session *session)
-{
-	if (atomic_inc_return(&session->metadata_cache->producing) == 1)
-		mutex_lock(&session->metadata_cache->lock);
-}
-
-static
-void lttng_metadata_end(struct lttng_session *session)
-{
-	WARN_ON_ONCE(!atomic_read(&session->metadata_cache->producing));
-	if (atomic_dec_return(&session->metadata_cache->producing) == 0) {
-		struct lttng_metadata_stream *stream;
-
-		list_for_each_entry(stream, &session->metadata_cache->metadata_stream, list)
-			wake_up_interruptible(&stream->read_wait);
-		mutex_unlock(&session->metadata_cache->lock);
-	}
-}
-
 /*
  * Write the metadata to the metadata cache.
  * Must be called with sessions_mutex held.
  * The metadata cache lock protects us from concurrent read access from
  * thread outputting metadata content to ring buffer.
- * The content of the printf is printed as a single atomic metadata
- * transaction.
  */
 int lttng_metadata_printf(struct lttng_session *session,
 			  const char *fmt, ...)
@@ -1778,8 +1687,9 @@ int lttng_metadata_printf(struct lttng_session *session,
 	char *str;
 	size_t len;
 	va_list ap;
+	struct lttng_metadata_stream *stream;
 
-	WARN_ON_ONCE(!LTTNG_READ_ONCE(session->active));
+	WARN_ON_ONCE(!READ_ONCE(session->active));
 
 	va_start(ap, fmt);
 	str = kvasprintf(GFP_KERNEL, fmt, ap);
@@ -1788,7 +1698,7 @@ int lttng_metadata_printf(struct lttng_session *session,
 		return -ENOMEM;
 
 	len = strlen(str);
-	WARN_ON_ONCE(!atomic_read(&session->metadata_cache->producing));
+	mutex_lock(&session->metadata_cache->lock);
 	if (session->metadata_cache->metadata_written + len >
 			session->metadata_cache->cache_alloc) {
 		char *tmp_cache_realloc;
@@ -1797,7 +1707,7 @@ int lttng_metadata_printf(struct lttng_session *session,
 		tmp_cache_alloc_size = max_t(unsigned int,
 				session->metadata_cache->cache_alloc + len,
 				session->metadata_cache->cache_alloc << 1);
-		tmp_cache_realloc = lttng_vzalloc(tmp_cache_alloc_size);
+		tmp_cache_realloc = vzalloc(tmp_cache_alloc_size);
 		if (!tmp_cache_realloc)
 			goto err;
 		if (session->metadata_cache->data) {
@@ -1814,11 +1724,16 @@ int lttng_metadata_printf(struct lttng_session *session,
 			session->metadata_cache->metadata_written,
 			str, len);
 	session->metadata_cache->metadata_written += len;
+	mutex_unlock(&session->metadata_cache->lock);
 	kfree(str);
 
+	list_for_each_entry(stream, &session->metadata_cache->metadata_stream, list)
+		wake_up_interruptible(&stream->read_wait);
+
 	return 0;
 
 err:
+	mutex_unlock(&session->metadata_cache->lock);
 	kfree(str);
 	return -ENOMEM;
 }
@@ -2355,8 +2270,6 @@ int _lttng_fields_metadata_statedump(struct lttng_session *session,
 
 /*
  * Must be called with sessions_mutex held.
- * The entire event metadata is printed as a single atomic metadata
- * transaction.
  */
 static
 int _lttng_event_metadata_statedump(struct lttng_session *session,
@@ -2365,13 +2278,11 @@ int _lttng_event_metadata_statedump(struct lttng_session *session,
 {
 	int ret = 0;
 
-	if (event->metadata_dumped || !LTTNG_READ_ONCE(session->active))
+	if (event->metadata_dumped || !READ_ONCE(session->active))
 		return 0;
 	if (chan->channel_type == METADATA_CHANNEL)
 		return 0;
 
-	lttng_metadata_begin(session);
-
 	ret = lttng_metadata_printf(session,
 		"event {\n"
 		"	name = \"%s\";\n"
@@ -2421,15 +2332,12 @@ int _lttng_event_metadata_statedump(struct lttng_session *session,
 
 	event->metadata_dumped = 1;
 end:
-	lttng_metadata_end(session);
 	return ret;
 
 }
 
 /*
  * Must be called with sessions_mutex held.
- * The entire channel metadata is printed as a single atomic metadata
- * transaction.
  */
 static
 int _lttng_channel_metadata_statedump(struct lttng_session *session,
@@ -2437,14 +2345,12 @@ int _lttng_channel_metadata_statedump(struct lttng_session *session,
 {
 	int ret = 0;
 
-	if (chan->metadata_dumped || !LTTNG_READ_ONCE(session->active))
+	if (chan->metadata_dumped || !READ_ONCE(session->active))
 		return 0;
 
 	if (chan->channel_type == METADATA_CHANNEL)
 		return 0;
 
-	lttng_metadata_begin(session);
-
 	WARN_ON_ONCE(!chan->header_type);
 	ret = lttng_metadata_printf(session,
 		"stream {\n"
@@ -2478,7 +2384,6 @@ int _lttng_channel_metadata_statedump(struct lttng_session *session,
 
 	chan->metadata_dumped = 1;
 end:
-	lttng_metadata_end(session);
 	return ret;
 }
 
@@ -2598,7 +2503,7 @@ int64_t measure_clock_offset(void)
 static
 int print_escaped_ctf_string(struct lttng_session *session, const char *string)
 {
-	int ret;
+	int ret = 0;
 	size_t i;
 	char cur;
 
@@ -2659,15 +2564,13 @@ int _lttng_session_metadata_statedump(struct lttng_session *session)
 {
 	unsigned char *uuid_c = session->uuid.b;
 	unsigned char uuid_s[37], clock_uuid_s[BOOT_ID_LEN];
+	const char *product_uuid;
 	struct lttng_channel *chan;
 	struct lttng_event *event;
 	int ret = 0;
 
-	if (!LTTNG_READ_ONCE(session->active))
+	if (!READ_ONCE(session->active))
 		return 0;
-
-	lttng_metadata_begin(session);
-
 	if (session->metadata_dumped)
 		goto skip_session;
 
@@ -2748,7 +2651,18 @@ int _lttng_session_metadata_statedump(struct lttng_session *session)
 	if (ret)
 		goto end;
 
-	/* Close env */
+	/* Add the product UUID to the 'env' section */
+	product_uuid = dmi_get_system_info(DMI_PRODUCT_UUID);
+	if (product_uuid) {
+		ret = lttng_metadata_printf(session,
+				"	product_uuid = \"%s\";\n",
+				product_uuid
+				);
+		if (ret)
+			goto end;
+	}
+
+	/* Close the 'env' section */
 	ret = lttng_metadata_printf(session, "};\n\n");
 	if (ret)
 		goto end;
@@ -2829,7 +2743,6 @@ skip_session:
 	}
 	session->metadata_dumped = 1;
 end:
-	lttng_metadata_end(session);
 	return ret;
 }
 
@@ -2840,9 +2753,9 @@ end:
  * Registers a transport which can be used as output to extract the data out of
  * LTTng. The module calling this registration function must ensure that no
  * trap-inducing code will be executed by the transport functions. E.g.
- * vmalloc_sync_mappings() must be called between a vmalloc and the moment the memory
+ * vmalloc_sync_all() must be called between a vmalloc and the moment the memory
  * is made visible to the transport function. This registration acts as a
- * vmalloc_sync_mappings. Therefore, only if the module allocates virtual memory
+ * vmalloc_sync_all. Therefore, only if the module allocates virtual memory
  * after its registration must it synchronize the TLBs.
  */
 void lttng_transport_register(struct lttng_transport *transport)
@@ -2850,9 +2763,9 @@ void lttng_transport_register(struct lttng_transport *transport)
 	/*
 	 * Make sure no page fault can be triggered by the module about to be
 	 * registered. We deal with this here so we don't have to call
-	 * vmalloc_sync_mappings() in each module's init.
+	 * vmalloc_sync_all() in each module's init.
 	 */
-	wrapper_vmalloc_sync_mappings();
+	wrapper_vmalloc_sync_all();
 
 	mutex_lock(&sessions_mutex);
 	list_add_tail(&transport->node, &lttng_transport_list);
@@ -2872,7 +2785,7 @@ void lttng_transport_unregister(struct lttng_transport *transport)
 }
 EXPORT_SYMBOL_GPL(lttng_transport_unregister);
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,10,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,10,0))
 
 enum cpuhp_state lttng_hp_prepare;
 enum cpuhp_state lttng_hp_online;
@@ -2988,7 +2901,7 @@ static void __exit lttng_exit_cpu_hotplug(void)
 	cpuhp_remove_multi_state(lttng_hp_prepare);
 }
 
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,10,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,10,0)) */
 static int lttng_init_cpu_hotplug(void)
 {
 	return 0;
@@ -2996,7 +2909,7 @@ static int lttng_init_cpu_hotplug(void)
 static void lttng_exit_cpu_hotplug(void)
 {
 }
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,10,0)) */
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,10,0)) */
 
 
 static int __init lttng_events_init(void)
