@@ -10,7 +10,7 @@
 #ifndef _LTTNG_EVENTS_H
 #define _LTTNG_EVENTS_H
 
-#include <lttng-kernel-version.h>
+#include <linux/version.h>
 #include <linux/list.h>
 #include <linux/kprobes.h>
 #include <linux/kref.h>
@@ -21,7 +21,7 @@
 #include <lttng-abi.h>
 #include <lttng-abi-old.h>
 
-#define lttng_is_signed_type(type)	(((type) -1) < (type) 1)
+#define lttng_is_signed_type(type)	(((type)(-1)) < 0)
 
 struct lttng_channel;
 struct lttng_session;
@@ -175,7 +175,7 @@ union lttng_ctx_value {
  * lttng_ctx_field because cpu hotplug needs fixed-location addresses.
  */
 struct lttng_perf_counter_field {
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,10,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,10,0))
 	struct lttng_cpuhp_node cpuhp_prepare;
 	struct lttng_cpuhp_node cpuhp_online;
 #else
@@ -292,16 +292,6 @@ struct lttng_uprobe_handler {
 	struct list_head node;
 };
 
-enum lttng_syscall_entryexit {
-	LTTNG_SYSCALL_ENTRY,
-	LTTNG_SYSCALL_EXIT,
-};
-
-enum lttng_syscall_abi {
-	LTTNG_SYSCALL_ABI_NATIVE,
-	LTTNG_SYSCALL_ABI_COMPAT,
-};
-
 /*
  * lttng_event structure is referred to by the tracing fast path. It must be
  * kept small.
@@ -328,11 +318,6 @@ struct lttng_event {
 			struct inode *inode;
 			struct list_head head;
 		} uprobe;
-		struct {
-			char *syscall_name;
-			enum lttng_syscall_entryexit entryexit;
-			enum lttng_syscall_abi abi;
-		} syscall;
 	} u;
 	struct list_head list;		/* Event list in session */
 	unsigned int metadata_dumped:1;
@@ -472,10 +457,10 @@ struct lttng_channel {
 	struct lttng_syscall_filter *sc_filter;
 	int header_type;		/* 0: unset, 1: compact, 2: large */
 	enum channel_type channel_type;
-	int syscall_all;
 	unsigned int metadata_dumped:1,
 		sys_enter_registered:1,
 		sys_exit_registered:1,
+		syscall_all:1,
 		tstate:1;		/* Transient enable state */
 };
 
@@ -489,7 +474,6 @@ struct lttng_metadata_stream {
 	struct list_head list;		/* Stream list */
 	struct lttng_transport *transport;
 	uint64_t version;		/* Current version of the metadata cache */
-	bool coherent;			/* Stream in a coherent state */
 };
 
 #define LTTNG_DYNAMIC_LEN_STACK_SIZE	128
@@ -502,19 +486,36 @@ struct lttng_dynamic_len_stack {
 DECLARE_PER_CPU(struct lttng_dynamic_len_stack, lttng_dynamic_len_stack);
 
 /*
- * struct lttng_pid_tracker declared in header due to deferencing of *v
+ * struct lttng_id_tracker declared in header due to deferencing of *v
  * in RCU_INITIALIZER(v).
  */
-#define LTTNG_PID_HASH_BITS	6
-#define LTTNG_PID_TABLE_SIZE	(1 << LTTNG_PID_HASH_BITS)
+#define LTTNG_ID_HASH_BITS	6
+#define LTTNG_ID_TABLE_SIZE	(1 << LTTNG_ID_HASH_BITS)
 
-struct lttng_pid_tracker {
-	struct hlist_head pid_hash[LTTNG_PID_TABLE_SIZE];
+enum tracker_type {
+	TRACKER_PID,
+	TRACKER_VPID,
+	TRACKER_UID,
+	TRACKER_VUID,
+	TRACKER_GID,
+	TRACKER_VGID,
+
+	TRACKER_UNKNOWN,
 };
 
-struct lttng_pid_hash_node {
+struct lttng_id_tracker_rcu {
+	struct hlist_head id_hash[LTTNG_ID_TABLE_SIZE];
+};
+
+struct lttng_id_tracker {
+	struct lttng_session *session;
+	enum tracker_type tracker_type;
+	struct lttng_id_tracker_rcu *p;	/* RCU dereferenced. */
+};
+
+struct lttng_id_hash_node {
 	struct hlist_node hlist;
-	int pid;
+	int id;
 };
 
 struct lttng_session {
@@ -527,7 +528,12 @@ struct lttng_session {
 	unsigned int free_chan_id;	/* Next chan ID to allocate */
 	uuid_le uuid;			/* Trace session unique ID */
 	struct lttng_metadata_cache *metadata_cache;
-	struct lttng_pid_tracker *pid_tracker;
+	struct lttng_id_tracker pid_tracker;
+	struct lttng_id_tracker vpid_tracker;
+	struct lttng_id_tracker uid_tracker;
+	struct lttng_id_tracker vuid_tracker;
+	struct lttng_id_tracker gid_tracker;
+	struct lttng_id_tracker vgid_tracker;
 	unsigned int metadata_dumped:1,
 		tstate:1;		/* Transient enable state */
 	/* List of enablers */
@@ -542,7 +548,6 @@ struct lttng_metadata_cache {
 	char *data;			/* Metadata cache */
 	unsigned int cache_alloc;	/* Metadata allocated size (bytes) */
 	unsigned int metadata_written;	/* Number of bytes written in metadata cache */
-	atomic_t producing;		/* Metadata being produced (incomplete) */
 	struct kref refcount;		/* Metadata cache usage */
 	struct list_head metadata_stream;	/* Metadata stream list */
 	uuid_le uuid;			/* Trace session unique ID (copy) */
@@ -623,19 +628,22 @@ int lttng_probes_init(void);
 void lttng_probes_exit(void);
 
 int lttng_metadata_output_channel(struct lttng_metadata_stream *stream,
-		struct channel *chan, bool *coherent);
+		struct channel *chan);
 
-int lttng_pid_tracker_get_node_pid(const struct lttng_pid_hash_node *node);
-struct lttng_pid_tracker *lttng_pid_tracker_create(void);
-void lttng_pid_tracker_destroy(struct lttng_pid_tracker *lpf);
-bool lttng_pid_tracker_lookup(struct lttng_pid_tracker *lpf, int pid);
-int lttng_pid_tracker_add(struct lttng_pid_tracker *lpf, int pid);
-int lttng_pid_tracker_del(struct lttng_pid_tracker *lpf, int pid);
+int lttng_id_tracker_get_node_id(const struct lttng_id_hash_node *node);
+int lttng_id_tracker_empty_set(struct lttng_id_tracker *lf);
+void lttng_id_tracker_destroy(struct lttng_id_tracker *lf, bool rcu);
+bool lttng_id_tracker_lookup(struct lttng_id_tracker_rcu *p, int id);
+int lttng_id_tracker_add(struct lttng_id_tracker *lf, int id);
+int lttng_id_tracker_del(struct lttng_id_tracker *lf, int id);
 
-int lttng_session_track_pid(struct lttng_session *session, int pid);
-int lttng_session_untrack_pid(struct lttng_session *session, int pid);
+int lttng_session_track_id(struct lttng_session *session,
+		enum tracker_type tracker_type, int id);
+int lttng_session_untrack_id(struct lttng_session *session,
+		enum tracker_type tracker_type, int id);
 
-int lttng_session_list_tracker_pids(struct lttng_session *session);
+int lttng_session_list_tracker_ids(struct lttng_session *session,
+		enum tracker_type tracker_type);
 
 void lttng_clock_ref(void);
 void lttng_clock_unref(void);
@@ -643,11 +651,10 @@ void lttng_clock_unref(void);
 #if defined(CONFIG_HAVE_SYSCALL_TRACEPOINTS)
 int lttng_syscalls_register(struct lttng_channel *chan, void *filter);
 int lttng_syscalls_unregister(struct lttng_channel *chan);
-int lttng_syscalls_destroy(struct lttng_channel *chan);
 int lttng_syscall_filter_enable(struct lttng_channel *chan,
-		struct lttng_event *event);
+		const char *name);
 int lttng_syscall_filter_disable(struct lttng_channel *chan,
-		struct lttng_event *event);
+		const char *name);
 long lttng_channel_syscall_mask(struct lttng_channel *channel,
 		struct lttng_kernel_syscall_mask __user *usyscall_mask);
 #else
@@ -661,19 +668,14 @@ static inline int lttng_syscalls_unregister(struct lttng_channel *chan)
 	return 0;
 }
 
-static inline int lttng_syscalls_destroy(struct lttng_channel *chan)
-{
-	return 0;
-}
-
 static inline int lttng_syscall_filter_enable(struct lttng_channel *chan,
-		struct lttng_event *event);
+		const char *name)
 {
 	return -ENOSYS;
 }
 
 static inline int lttng_syscall_filter_disable(struct lttng_channel *chan,
-		struct lttng_event *event);
+		const char *name)
 {
 	return -ENOSYS;
 }
@@ -690,7 +692,6 @@ int lttng_enabler_attach_bytecode(struct lttng_enabler *enabler,
 		struct lttng_kernel_filter_bytecode __user *bytecode);
 void lttng_enabler_event_link_bytecode(struct lttng_event *event,
 		struct lttng_enabler *enabler);
-void lttng_free_event_filter_runtime(struct lttng_event *event);
 
 int lttng_probes_init(void);
 
@@ -739,7 +740,98 @@ int lttng_add_migratable_to_ctx(struct lttng_ctx **ctx)
 
 int lttng_add_callstack_to_ctx(struct lttng_ctx **ctx, int type);
 
-#if defined(CONFIG_PERF_EVENTS) && (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,33))
+#if defined(CONFIG_CGROUPS) && \
+	((LINUX_VERSION_CODE >= KERNEL_VERSION(4,6,0)) || \
+	 LTTNG_UBUNTU_KERNEL_RANGE(4,4,0,0, 4,5,0,0))
+int lttng_add_cgroup_ns_to_ctx(struct lttng_ctx **ctx);
+#else
+static inline
+int lttng_add_cgroup_ns_to_ctx(struct lttng_ctx **ctx)
+{
+	return -ENOSYS;
+}
+#endif
+
+#if defined(CONFIG_IPC_NS) && \
+	(LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0))
+int lttng_add_ipc_ns_to_ctx(struct lttng_ctx **ctx);
+#else
+static inline
+int lttng_add_ipc_ns_to_ctx(struct lttng_ctx **ctx)
+{
+	return -ENOSYS;
+}
+#endif
+
+#if !defined(LTTNG_MNT_NS_MISSING_HEADER) && \
+	(LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0))
+int lttng_add_mnt_ns_to_ctx(struct lttng_ctx **ctx);
+#else
+static inline
+int lttng_add_mnt_ns_to_ctx(struct lttng_ctx **ctx)
+{
+	return -ENOSYS;
+}
+#endif
+
+#if defined(CONFIG_NET_NS) && \
+	(LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0))
+int lttng_add_net_ns_to_ctx(struct lttng_ctx **ctx);
+#else
+static inline
+int lttng_add_net_ns_to_ctx(struct lttng_ctx **ctx)
+{
+	return -ENOSYS;
+}
+#endif
+
+#if defined(CONFIG_PID_NS) && \
+	(LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0))
+int lttng_add_pid_ns_to_ctx(struct lttng_ctx **ctx);
+#else
+static inline
+int lttng_add_pid_ns_to_ctx(struct lttng_ctx **ctx)
+{
+	return -ENOSYS;
+}
+#endif
+
+#if defined(CONFIG_USER_NS) && \
+	(LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0))
+int lttng_add_user_ns_to_ctx(struct lttng_ctx **ctx);
+#else
+static inline
+int lttng_add_user_ns_to_ctx(struct lttng_ctx **ctx)
+{
+	return -ENOSYS;
+}
+#endif
+
+#if defined(CONFIG_UTS_NS) && \
+	(LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0))
+int lttng_add_uts_ns_to_ctx(struct lttng_ctx **ctx);
+#else
+static inline
+int lttng_add_uts_ns_to_ctx(struct lttng_ctx **ctx)
+{
+	return -ENOSYS;
+}
+#endif
+
+int lttng_add_uid_to_ctx(struct lttng_ctx **ctx);
+int lttng_add_euid_to_ctx(struct lttng_ctx **ctx);
+int lttng_add_suid_to_ctx(struct lttng_ctx **ctx);
+int lttng_add_gid_to_ctx(struct lttng_ctx **ctx);
+int lttng_add_egid_to_ctx(struct lttng_ctx **ctx);
+int lttng_add_sgid_to_ctx(struct lttng_ctx **ctx);
+int lttng_add_vuid_to_ctx(struct lttng_ctx **ctx);
+int lttng_add_veuid_to_ctx(struct lttng_ctx **ctx);
+int lttng_add_vsuid_to_ctx(struct lttng_ctx **ctx);
+int lttng_add_vgid_to_ctx(struct lttng_ctx **ctx);
+int lttng_add_vegid_to_ctx(struct lttng_ctx **ctx);
+int lttng_add_vsgid_to_ctx(struct lttng_ctx **ctx);
+
+#if defined(CONFIG_PERF_EVENTS)
 int lttng_add_perf_counter_to_ctx(uint32_t type,
 				  uint64_t config,
 				  const char *name,
@@ -888,8 +980,6 @@ int lttng_calibrate(struct lttng_kernel_calibrate *calibrate);
 extern const struct file_operations lttng_tracepoint_list_fops;
 extern const struct file_operations lttng_syscall_list_fops;
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35))
 #define TRACEPOINT_HAS_DATA_ARG
-#endif
 
 #endif /* _LTTNG_EVENTS_H */
