@@ -15,10 +15,11 @@
 #include <probes/lttng.h>
 #include <probes/lttng-types.h>
 #include <probes/lttng-probe-user.h>
-#include <wrapper/vmalloc.h>	/* for wrapper_vmalloc_sync_mappings() */
+#include <wrapper/vmalloc.h>	/* for wrapper_vmalloc_sync_all() */
 #include <wrapper/ringbuffer/frontend_types.h>
 #include <wrapper/ringbuffer/backend.h>
 #include <wrapper/rcu.h>
+#include <wrapper/user_namespace.h>
 #include <lttng-events.h>
 #include <lttng-tracer-core.h>
 #include <lttng-tp-mempool.h>
@@ -1127,18 +1128,37 @@ static void __event_probe__##_name(void *__data, _proto)		      \
 	struct probe_local_vars __tp_locvar;				      \
 	struct probe_local_vars *tp_locvar __attribute__((unused)) =	      \
 			&__tp_locvar;					      \
-	struct lttng_pid_tracker *__lpf;				      \
+	struct lttng_id_tracker_rcu *__lf;				      \
 									      \
 	if (!_TP_SESSION_CHECK(session, __session))			      \
 		return;							      \
-	if (unlikely(!LTTNG_READ_ONCE(__session->active)))		      \
+	if (unlikely(!READ_ONCE(__session->active)))			      \
 		return;							      \
-	if (unlikely(!LTTNG_READ_ONCE(__chan->enabled)))		      \
+	if (unlikely(!READ_ONCE(__chan->enabled)))			      \
 		return;							      \
-	if (unlikely(!LTTNG_READ_ONCE(__event->enabled)))		      \
+	if (unlikely(!READ_ONCE(__event->enabled)))			      \
 		return;							      \
-	__lpf = lttng_rcu_dereference(__session->pid_tracker);		      \
-	if (__lpf && likely(!lttng_pid_tracker_lookup(__lpf, current->tgid))) \
+	__lf = lttng_rcu_dereference(__session->pid_tracker.p);		      \
+	if (__lf && likely(!lttng_id_tracker_lookup(__lf, current->tgid)))    \
+		return;							      \
+	__lf = lttng_rcu_dereference(__session->vpid_tracker.p);	      \
+	if (__lf && likely(!lttng_id_tracker_lookup(__lf, task_tgid_vnr(current)))) \
+		return;							      \
+	__lf = lttng_rcu_dereference(__session->uid_tracker.p);		      \
+	if (__lf && likely(!lttng_id_tracker_lookup(__lf,		      \
+			lttng_current_uid())))				      \
+		return;							      \
+	__lf = lttng_rcu_dereference(__session->vuid_tracker.p);	      \
+	if (__lf && likely(!lttng_id_tracker_lookup(__lf,		      \
+			lttng_current_vuid())))				      \
+		return;							      \
+	__lf = lttng_rcu_dereference(__session->gid_tracker.p);		      \
+	if (__lf && likely(!lttng_id_tracker_lookup(__lf,		      \
+			lttng_current_gid())))				      \
+		return;							      \
+	__lf = lttng_rcu_dereference(__session->vgid_tracker.p);	      \
+	if (__lf && likely(!lttng_id_tracker_lookup(__lf,		      \
+			lttng_current_vgid())))				      \
 		return;							      \
 	__orig_dynamic_len_offset = this_cpu_ptr(&lttng_dynamic_len_stack)->offset; \
 	__dynamic_len_idx = __orig_dynamic_len_offset;			      \
@@ -1201,18 +1221,37 @@ static void __event_probe__##_name(void *__data)			      \
 	struct probe_local_vars __tp_locvar;				      \
 	struct probe_local_vars *tp_locvar __attribute__((unused)) =	      \
 			&__tp_locvar;					      \
-	struct lttng_pid_tracker *__lpf;				      \
+	struct lttng_id_tracker_rcu *__lf;				      \
 									      \
 	if (!_TP_SESSION_CHECK(session, __session))			      \
 		return;							      \
-	if (unlikely(!LTTNG_READ_ONCE(__session->active)))		      \
+	if (unlikely(!READ_ONCE(__session->active)))			      \
 		return;							      \
-	if (unlikely(!LTTNG_READ_ONCE(__chan->enabled)))		      \
+	if (unlikely(!READ_ONCE(__chan->enabled)))			      \
 		return;							      \
-	if (unlikely(!LTTNG_READ_ONCE(__event->enabled)))		      \
+	if (unlikely(!READ_ONCE(__event->enabled)))			      \
 		return;							      \
-	__lpf = lttng_rcu_dereference(__session->pid_tracker);		      \
-	if (__lpf && likely(!lttng_pid_tracker_lookup(__lpf, current->tgid)))  \
+	__lf = lttng_rcu_dereference(__session->pid_tracker.p);		      \
+	if (__lf && likely(!lttng_id_tracker_lookup(__lf, current->tgid)))    \
+		return;							      \
+	__lf = lttng_rcu_dereference(__session->vpid_tracker.p);	      \
+	if (__lf && likely(!lttng_id_tracker_lookup(__lf, task_tgid_vnr(current)))) \
+		return;							      \
+	__lf = lttng_rcu_dereference(__session->uid_tracker.p);		      \
+	if (__lf && likely(!lttng_id_tracker_lookup(__lf,		      \
+			lttng_current_uid())))				      \
+		return;							      \
+	__lf = lttng_rcu_dereference(__session->vuid_tracker.p);	      \
+	if (__lf && likely(!lttng_id_tracker_lookup(__lf,		      \
+			lttng_current_vuid())))				      \
+		return;							      \
+	__lf = lttng_rcu_dereference(__session->gid_tracker.p);		      \
+	if (__lf && likely(!lttng_id_tracker_lookup(__lf,		      \
+			lttng_current_gid())))				      \
+		return;							      \
+	__lf = lttng_rcu_dereference(__session->vgid_tracker.p);	      \
+	if (__lf && likely(!lttng_id_tracker_lookup(__lf,		      \
+			lttng_current_vgid())))				      \
 		return;							      \
 	__orig_dynamic_len_offset = this_cpu_ptr(&lttng_dynamic_len_stack)->offset; \
 	__dynamic_len_idx = __orig_dynamic_len_offset;			      \
@@ -1352,7 +1391,7 @@ static __used struct lttng_probe_desc TP_ID(__probe_desc___, TRACE_SYSTEM) = {
 #ifndef TP_MODULE_NOINIT
 static int TP_ID(__lttng_events_init__, TRACE_SYSTEM)(void)
 {
-	wrapper_vmalloc_sync_mappings();
+	wrapper_vmalloc_sync_all();
 	return lttng_probe_register(&TP_ID(__probe_desc___, TRACE_SYSTEM));
 }
 
