@@ -10,7 +10,6 @@
  */
 
 #include <lttng-kernel-version.h>
-#include <linux/module.h>
 
 #if (defined(CONFIG_KALLSYMS) \
 	&& (LINUX_VERSION_CODE < KERNEL_VERSION(3,4,0)))
@@ -35,7 +34,6 @@ struct irq_desc *wrapper_irq_to_desc(unsigned int irq)
 		return NULL;
 	}
 }
-EXPORT_SYMBOL_GPL(wrapper_irq_to_desc);
 
 #else
 
@@ -46,6 +44,5 @@ struct irq_desc *wrapper_irq_to_desc(unsigned int irq)
 {
 	return irq_to_desc(irq);
 }
-EXPORT_SYMBOL_GPL(wrapper_irq_to_desc);
 
 #endif
