@@ -10,24 +10,10 @@
 #ifndef _LTTNG_WRAPPER_TRACEPOINT_H
 #define _LTTNG_WRAPPER_TRACEPOINT_H
 
-#include <lttng-kernel-version.h>
+#include <linux/version.h>
 #include <linux/tracepoint.h>
 #include <linux/module.h>
 
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(2,6,35))
-
-#define DECLARE_EVENT_CLASS(name, proto, args, tstruct, assign, print)
-
-#endif
-
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,10,0))
-#define LTTNG_DEFINE_TRACE(name, proto, args)		\
-	DEFINE_TRACE(name, PARAMS(proto), PARAMS(args))
-#else
-#define LTTNG_DEFINE_TRACE(name, proto, args)		\
-	DEFINE_TRACE(name)
-#endif
-
 #ifndef HAVE_KABI_2635_TRACEPOINT
 
 #define kabi_2635_tracepoint_probe_register tracepoint_probe_register
@@ -35,14 +21,14 @@
 
 #endif /* HAVE_KABI_2635_TRACEPOINT */
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,15,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,15,0))
 
 #include <lttng-tracepoint.h>
 
 #define lttng_wrapper_tracepoint_probe_register lttng_tracepoint_probe_register
 #define lttng_wrapper_tracepoint_probe_unregister lttng_tracepoint_probe_unregister
 
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,15,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,15,0)) */
 
 #define lttng_wrapper_tracepoint_probe_register kabi_2635_tracepoint_probe_register
 #define lttng_wrapper_tracepoint_probe_unregister kabi_2635_tracepoint_probe_unregister
@@ -58,9 +44,9 @@ void lttng_tracepoint_exit(void)
 {
 }
 
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,15,0)) */
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,15,0)) */
 
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,15,0) && defined(CONFIG_MODULE_SIG))
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(3,15,0) && defined(CONFIG_MODULE_SIG))
 
 #include <linux/kallsyms.h>
 #include <wrapper/kallsyms.h>
@@ -82,20 +68,9 @@ int wrapper_tracepoint_module_notify(struct notifier_block *nb,
 	}
 }
 
-/*
- * No canary for 'tracepoint_module_notify()', it's only defined in 'kernel/tracepoint.c'.
- *
- * static inline
- * int __canary__tracepoint_module_notify(struct notifier_block *nb,
- * 		unsigned long val, struct module *mod)
- * {
- * 	return tracepoint_module_notify(nb, val, mod);
- * }
- */
+#endif /* #if (LINUX_VERSION_CODE < KERNEL_VERSION(3,15,0) && defined(CONFIG_MODULE_SIG)) */
 
-#endif /* #if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,15,0) && defined(CONFIG_MODULE_SIG)) */
-
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,15,0) && defined(CONFIG_MODULE_SIG) && defined(MODULE))
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(3,15,0) && defined(CONFIG_MODULE_SIG) && defined(MODULE))
 
 static inline
 int wrapper_lttng_fixup_sig(struct module *mod)
@@ -116,7 +91,7 @@ int wrapper_lttng_fixup_sig(struct module *mod)
 	return ret;
 }
 
-#else /* #if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,15,0) && defined(CONFIG_MODULE_SIG) && defined(MODULE)) */
+#else /* #if (LINUX_VERSION_CODE < KERNEL_VERSION(3,15,0) && defined(CONFIG_MODULE_SIG) && defined(MODULE)) */
 
 static inline
 int wrapper_lttng_fixup_sig(struct module *mod)
@@ -124,18 +99,18 @@ int wrapper_lttng_fixup_sig(struct module *mod)
 	return 0;
 }
 
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,15,0) && defined(CONFIG_MODULE_SIG) && defined(MODULE)) */
+#endif /* #else #if (LINUX_VERSION_CODE < KERNEL_VERSION(3,15,0) && defined(CONFIG_MODULE_SIG) && defined(MODULE)) */
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,19,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,19,0))
 static inline struct tracepoint *lttng_tracepoint_ptr_deref(tracepoint_ptr_t *p)
 {
 	return tracepoint_ptr_deref(p);
 }
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,19,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,19,0)) */
 static inline struct tracepoint *lttng_tracepoint_ptr_deref(struct tracepoint * const *p)
 {
 	return *p;
 }
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,19,0)) */
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,19,0)) */
 
 #endif /* _LTTNG_WRAPPER_TRACEPOINT_H */
